@@ -134,6 +134,8 @@ class RaggedMmap:
         numpy.from_ndarray(out_dir / ends_key, np.array(numpy_bytes_slices.ends, dtype=np.int64))
         shapes_are_flat = all([len(shape) == 1 for shape in numpy_bytes_slices.shapes])
         base._int_to_file(int(shapes_are_flat), out_dir / "shapes_are_flat.ninja")
+        base._str_to_file("ragged", out_dir / "type.ninja")
+
         if shapes_are_flat:
             numpy.from_ndarray(out_dir / shapes_key, numpy_bytes_slices.shapes)
         else:
@@ -154,7 +156,7 @@ class RaggedMmap:
 
     @classmethod
     def from_generator(cls, out_dir: Union[str, Path], sample_generator, batch_size: int, verbose=False, **kwargs):
-        return base._from_generator_base(
+        return base.from_generator_base(
             out_dir=out_dir,
             sample_generator=sample_generator,
             batch_size=batch_size,
